package com.ruoyi.ems.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.ems.mapper.EmsElecStoreHMapper;
import com.ruoyi.ems.domain.ElecStoreH;
import com.ruoyi.ems.service.IElecStoreHService;

/**
 * 储能计量-小时Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-08-09
 */
@Service
public class ElecStoreHServiceImpl implements IElecStoreHService
{
    @Autowired
    private EmsElecStoreHMapper elecStoreHMapper;

    /**
     * 查询储能计量-小时
     * 
     * @param id 储能计量-小时主键
     * @return 储能计量-小时
     */
    @Override
    public ElecStoreH selectElecStoreHById(Long id)
    {
        return elecStoreHMapper.selectEmsElecStoreHById(id);
    }

    /**
     * 查询储能计量-小时列表
     * 
     * @param admEmsElecStoreH 储能计量-小时
     * @return 储能计量-小时
     */
    @Override
    public List<ElecStoreH> selectElecStoreHList(ElecStoreH admEmsElecStoreH)
    {
        return elecStoreHMapper.selectEmsElecStoreHList(admEmsElecStoreH);
    }

    /**
     * 新增储能计量-小时
     * 
     * @param admEmsElecStoreH 储能计量-小时
     * @return 结果
     */
    @Override
    public int insertElecStoreH(ElecStoreH admEmsElecStoreH)
    {
        return elecStoreHMapper.insertEmsElecStoreH(admEmsElecStoreH);
    }

    /**
     * 修改储能计量-小时
     * 
     * @param admEmsElecStoreH 储能计量-小时
     * @return 结果
     */
    @Override
    public int updateElecStoreH(ElecStoreH admEmsElecStoreH)
    {
        return elecStoreHMapper.updateEmsElecStoreH(admEmsElecStoreH);
    }

    /**
     * 批量删除储能计量-小时
     * 
     * @param ids 需要删除的储能计量-小时主键
     * @return 结果
     */
    @Override
    public int deleteElecStoreHByIds(Long[] ids)
    {
        return elecStoreHMapper.deleteEmsElecStoreHByIds(ids);
    }

    /**
     * 删除储能计量-小时信息
     * 
     * @param id 储能计量-小时主键
     * @return 结果
     */
    @Override
    public int deleteElecStoreHById(Long id)
    {
        return elecStoreHMapper.deleteEmsElecStoreHById(id);
    }
}
