package com.ruoyi.ems.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.ems.domain.ElecStoreH;
import com.ruoyi.ems.service.IElecStoreHService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 储能计量-小时Controller
 *
 * @author ruoyi
 * @date 2024-08-09
 */
@RestController
@RequestMapping("/elec/store/hour")
@Api(value = "ElecStoreHController", description = "能计量-小时数据接口")
public class ElecStoreHController extends BaseController
{
    @Autowired
    private IElecStoreHService elecStoreHService;

    /**
     * 查询储能计量-小时列表
     */
    @RequiresPermissions("power-mgr:gs:list")
    @GetMapping("/list")
    public TableDataInfo list(ElecStoreH admEmsElecStoreH)
    {
        startPage();
        List<ElecStoreH> list = elecStoreHService.selectElecStoreHList(admEmsElecStoreH);
        return getDataTable(list);
    }

    /**
     * 导出储能计量-小时列表
     */
    @RequiresPermissions("power-mgr:gs:export")
    @Log(title = "储能计量-小时", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ElecStoreH admEmsElecStoreH)
    {
        List<ElecStoreH> list = elecStoreHService.selectElecStoreHList(admEmsElecStoreH);
        ExcelUtil<ElecStoreH> util = new ExcelUtil<ElecStoreH>(ElecStoreH.class);
        util.exportExcel(response, list, "储能计量-小时数据");
    }

    /**
     * 获取储能计量-小时详细信息
     */
    @RequiresPermissions("power-mgr:gs:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(elecStoreHService.selectElecStoreHById(id));
    }

    /**
     * 新增储能计量-小时
     */
    @RequiresPermissions("power-mgr:gs:add")
    @Log(title = "储能计量-小时", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ElecStoreH admEmsElecStoreH)
    {
        return toAjax(elecStoreHService.insertElecStoreH(admEmsElecStoreH));
    }

    /**
     * 修改储能计量-小时
     */
    @RequiresPermissions("power-mgr:gs:edit")
    @Log(title = "储能计量-小时", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ElecStoreH admEmsElecStoreH)
    {
        return toAjax(elecStoreHService.updateElecStoreH(admEmsElecStoreH));
    }

    /**
     * 删除储能计量-小时
     */
    @RequiresPermissions("power-mgr:gs:remove")
    @Log(title = "储能计量-小时", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(elecStoreHService.deleteElecStoreHByIds(ids));
    }
}
